pread

Function pread 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pread( fildes: c_int, buf: *mut c_void, nbyte: size_t, offset: off_t, ) -> ssize_t
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/read.html.

Equivalent to read(), except that it shall read from a given position in the file without changing the file offset.

When successful, returns a non-negative number indicating the number of bytes actually read. Upon failure, returns -1.