read

Function read 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn read( fildes: c_int, buf: *mut c_void, nbyte: size_t, ) -> ssize_t
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/read.html.

Attempts to read nbyte bytes from the file associated with the open file descriptor, fildes, into the buffer pointed to by buf.

When successful, returns a non-negative number indicating the number of bytes actually read. Upon failure, returns -1.