#[unsafe(no_mangle)]pub unsafe extern "C" fn pwrite(
fildes: c_int,
buf: *const c_void,
nbyte: size_t,
offset: off_t,
) -> ssize_tExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/write.html.
Equivalent to write(), except that it writes into a given position and
does not change the file offset (regardless of whether O_APPEND is set).
When successful, returns a non-negative number indicating the number of
bytes actually written to the file associated with fildes. Upon failure,
returns -1.