#[unsafe(no_mangle)]pub unsafe extern "C" fn write(
fildes: c_int,
buf: *const c_void,
nbyte: size_t,
) -> ssize_tExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/write.html.
Attempts to write nbyte bytes from the buffer pointed to by buf to the
file associated with the open file descriptor, fildes.
When successful, returns a non-negative number indicating the number of
bytes actually written to the file associated with fildes. Upon failure,
returns -1.